## iPhone 16 Pro Max vs Samsung’s S25 Ultra: Who did AI better?

I got an early, hands-on look at the new Samsung S25 lineup, most importantly the S25 Ultra. I was curious to see what the best of the best from Samsung was like compared to the Apple counterpart, the iPhone 16 Pro Max. What really stood out to me about these phones is that we have seemed to reach a peak when it comes to form factor. The rectangular, candy bar design breathes a lot of similarities across both devices and so do the internal specs. So the only thing left here to truly compare is going to be the software, user experience, and, of course, their AI. Let’s get into.

### Design comparison

Again, from a design standpoint, you are going to see a ton of similarities between these two phones. Samsung made some changes to their new S25 Ultra compared to last year. They shrunk the bezels ever so slightly to go from 6.8in on the screen to 6.9in on the screen (sound familiar?). They also curved the side railings a bit to make it a bit less cumbersome to hold. Additionally, Samsung was able to reduce the weight of the device by about 15g, which is pretty noticeable.

Both phones use titanium materials for the chassis, have the highest-quality glass, have a triple camera array and feel exceptionally premium in the hand. The biggest visual difference is that the S25 Ultra has more squared-off corners while the iPhone is rounded off. So, it just comes down to visual preferences.

### A18 Pro vs Snapdragon 8 Elite for Galaxy

I just wanted to give a quick breakdown of the internal specs of each of these.

| Feature | S25 Ultra | iPhone 16 Pro Max |
| --- | --- | --- |
| Single Core Geekbench | 3049 | 3539 |
| Multi Core Geekbench | 9793 | 8772 |
| Total Cores | 8 | 6 |
| Total RAM | 12GB | 8GB |
| Operating System | OneUI 7 | iOS 18.X |

So, at a glance, you can see that these are going to be very similar. The single-core score goes to the iPhone, but the multicore score goes to S25 because it has 2 additional cores. Again, these are just numbers, but in reality, when it comes to day-to-day tasks, both of these phones will be able to do it all and do it super efficiently. In my video, I tested how fast apps open and how quickly you can mash the shutter button to take images, and both did great. Viewing content on these is going to be the best of the best. So still, this truly comes down to preference and familiarity. But what both of these chips enable is going to be all the AI features that are coming.

Some other specs to consider of the S25 Ultra:

- 3NM processor
- 40% NPU Increase
- 37% CPU increase
- 30% GPU Increase
- 40% increase in ray tracing
- 18% FPS increase

### Galaxy AI vs Apple Intelligence

I want to caveat this section by saying that Apple Intelligence is still not out in its fullest form as of writing this. We are currently on iOS 18.2 with only a few of the Apple Intelligence features available. Many of the promised features from WWDC 2024 are still missing, most importantly.

## Samsung Galaxy S25 Series: The Biggest New AI Features

Samsung is launching a slew of new AI tools on the Galaxy S25 series, continuing the push it started last year with the introduction of Galaxy AI.

While the initial wave of Galaxy AI features focused on single use cases, such as editing a photo or translating a phone call, the new tools announced on Wednesday are intended to simplify navigating your phone in general. Such tools include the ability to execute actions in multiple apps using voice commands and speaking or typing in natural language when searching for photos or device settings.

The updates are another sign that smartphone makers like Samsung are increasingly leaning on AI to make their phones feel fresh and new at a time when annual hardware changes have become incremental. Apple and Google took similar approaches with the iPhone 16 and Pixel 9, both of which centered on new AI software. But Apple has been rolling out its suite of Apple Intelligence features in phases through software updates, whereas Samsung says its new crop of AI-powered functions will be available on the Galaxy S25 family at launch.

While the tools are launching on Samsung's newest phones, the company hasn't ruled out the possibility of trickling them down to older devices -- as it's done with certain Galaxy AI features. However, it hasn't announced specific plans to do so, and not all features are likely to be supported on previous-generation phones since they run on older and less capable processors.

### Cross app actions

Among the most significant new AI features is what Samsung is calling cross app actions. This essentially allows you to execute tasks that would normally require opening multiple apps with just a voice command. For example, you should be able to say something like, "Find me a vegan pet-friendly restaurant nearby and send it in a text message," or "Find the next Buffalo Bills game and add it to my calendar."

Apple is also updating Siri to take action within apps, although that functionality hasn't launched yet.

Samsung says cross app actions will use a combination of Samsung and Google's AI models depending on the action. So if your voice command is primarily centered on search, it'll likely use Google, but if it involves interacting with Samsung apps (like saving something to Samsung Notes), it may lean more on Samsung's tech.

At launch, Spotify and WhatsApp will be supported in addition to apps from Samsung and Google.

### AI Select

AI Select is a tool that suggests actions or apps based on the content of your phone's screen. For example, it may recommend capturing a GIF if you're watching a video, or setting an image as your phone's background.